@@ -192,7 +192,7 @@ class EnhancedLanguageModel:
         return 0
     def choose_next_word_dynamically(self, prefix: Tuple[str]) -> Optional[str]:
         model_priority = ['sixgram_model', 'fivegram_model', 'fourgram_model', 
-                         'trigram_model', 'bigram_model']
+                        'trigram_model', 'bigram_model']
         candidates = []
         for model_attr in model_priority:
             model = getattr(self, model_attr, None)
@@ -220,7 +220,7 @@ class EnhancedLanguageModel:
         chosen_word = random.choices(words, weights=scores, k=1)[0]
         return chosen_word
     def generate_sentence(self, start_words: Optional[List[str]] = None, 
-                         base_length: int = Config.DEFAULT_SENTENCE_LENGTH) -> str:
+                        base_length: int = Config.DEFAULT_SENTENCE_LENGTH) -> str:
         target_length = self._get_dynamic_sentence_length(base_length)
         if start_words is None:
             start_words = random.choice(list(self.trigram_model.keys()))
@@ -336,9 +336,9 @@ class EnhancedLanguageModel:
             corrected = corrected[0].upper() + corrected[1:] if len(corrected) > 1 else corrected.upper()
         return corrected
     def generate_text(self, num_sentences: int = Config.DEFAULT_NUM_SENTENCES,
-                     input_words: Optional[List[str]] = None,
-                     length: int = Config.DEFAULT_SENTENCE_LENGTH,
-                     use_progress_bar: bool = False) -> str:
+                    input_words: Optional[List[str]] = None,
+                    length: int = Config.DEFAULT_SENTENCE_LENGTH,
+                    use_progress_bar: bool = False) -> str:
         generated_sentences = []
         context_word = None
         last_entity_token = None
@@ -471,7 +471,14 @@ class EnhancedLanguageModel:
                     pickle.dump(model_data, f)
 
             instance.model = defaultdict(lambda: defaultdict(int), model)
-                                     text_file: str = Config.TEXT_PATH) -> EnhancedLanguageModel:
+            instance.total_counts = total_counts
+            logger.info(f"Model loaded successfully from {filename}")
+            return instance
+        except Exception as e:
+            logger.error(f"Error loading model from {filename}: {e}")
+
+                return text
+                                     text_file: str = Config.TEXT_PATH) -> 'EnhancedLanguageModel':
                 """
                 Model dosyası varsa yükler, yoksa text_file'dan yeni model oluşturur ve kaydeder.
                 """
@@ -486,26 +493,6 @@ class EnhancedLanguageModel:
                     language_model.save_model(model_file)
                     logger.info("Created and saved new model")
                 return language_model
-            instance.total_counts = total_counts
-            logger.info(f"Model loaded successfully from {filename}")
-            return instance
-        except Exception as e:
-            logger.error(f"Error loading model from {filename}: {e}")
-            raise
-
-class TextLoader:
-    @staticmethod
-    def load_text_from_file(file_path: str) -> Optional[str]:
-        try:
-            with open(file_path, 'r', encoding='utf-8') as file:
-                text = file.read()
-                text = ' '.join(text.split()).strip()
-                if NLP:
-                    doc = NLP(text)
-                    cleaned_tokens = [token.text for token in doc 
-                                    if not token.is_punct and not token.is_space]
-                    return ' '.join(cleaned_tokens)
-                return text
         except FileNotFoundError:
             logger.error(f"File not found: {file_path}")
             return None
@@ -514,7 +501,7 @@ class TextLoader:
             return None
 
 
-                         text_file: str = Config.TEXT_PATH) -> EnhancedLanguageModel:
+                        text_file: str = Config.TEXT_PATH) -> EnhancedLanguageModel:
     try:
         language_model = EnhancedLanguageModel.load_model(model_file)
         logger.info("Loaded existing model")
